"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ReactLoadablePlugin = void 0;

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

// Implementation of this PR: https://github.com/jamiebuilds/react-loadable/pull/132
// Modified to strip out unneeded results for Next's specific use case
var url = require('url');

function buildManifest(compiler, compilation) {
  var context = compiler.options.context;
  var manifest = {};
  compilation.chunks.forEach(function (chunk) {
    chunk.files.forEach(function (file) {
      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = chunk.modulesIterable[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var module = _step.value;
          var id = module.id;
          var name = typeof module.libIdent === 'function' ? module.libIdent({
            context: context
          }) : null; // If it doesn't end in `.js` Next.js can't handle it right now.

          if (!file.match(/\.js$/) || !file.match(/^static\/chunks\//)) {
            return;
          }

          var publicPath = url.resolve(compilation.outputOptions.publicPath || '', file);
          var currentModule = module;

          if (module.constructor.name === 'ConcatenatedModule') {
            currentModule = module.rootModule;
          }

          if (!manifest[currentModule.rawRequest]) {
            manifest[currentModule.rawRequest] = [];
          }

          manifest[currentModule.rawRequest].push({
            id: id,
            name: name,
            file: file,
            publicPath: publicPath
          });
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return != null) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }
    });
  });
  return manifest;
}

var ReactLoadablePlugin =
/*#__PURE__*/
function () {
  function ReactLoadablePlugin() {
    var opts = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    (0, _classCallCheck2.default)(this, ReactLoadablePlugin);
    this.filename = opts.filename;
  }

  (0, _createClass2.default)(ReactLoadablePlugin, [{
    key: "apply",
    value: function apply(compiler) {
      var _this = this;

      compiler.hooks.emit.tapAsync('ReactLoadableManifest', function (compilation, callback) {
        var manifest = buildManifest(compiler, compilation);
        var json = JSON.stringify(manifest, null, 2);
        compilation.assets[_this.filename] = {
          source: function source() {
            return json;
          },
          size: function size() {
            return json.length;
          }
        };
        callback();
      });
    }
  }]);
  return ReactLoadablePlugin;
}();

exports.ReactLoadablePlugin = ReactLoadablePlugin;